@@ -8,13 +8,6 @@ require "numru/misc"
 =module NumRu::GGraph and others in ggraph.rb
 
 ==Index
-* ((<class NumRu::GPhys (methods added)>))
-  * ((<first1D>))
-    Returns a 1D subset selecting the first elements of 2nd, 3rd, ..
-    dimensions, i.e., self[true, 0, 0, ...].
-  * ((<first2D>))
-    Returns a 2D subset selecting the first elements of 3rd, 4th, ..
-    dimensions, i.e., self[true, true, 0, 0, ...].
 * ((<module NumRu::GGraph>))
   * ((<title>))
     Shows title by (({DCL.uxmttl('t',string,0.0)})).
@@ -38,12 +31,12 @@ require "numru/misc"
     Set the option values effective only in the next call of ((<axes>))
     (cleared then).
   * ((<line>))
-    Plot a poly-line by selecting the first dimension (with ((<first1D>)))
+    Plot a poly-line by selecting the first dimension (with GPhys#first1D)
     if (({gphys})) is more than 2D.
   * ((<mark>))
     Similar to ((<line>)) but plots marks instead of drawing a poly-line.
   * ((<contour>))
-    Contour plot by selecting the first 2 dimensions (with ((<first2D>)))
+    Contour plot by selecting the first 2 dimensions (with GPhys#first2D)
     if (({gphys})) is more than 3D.
   * ((<set_contour_levels>))
     Set contour levels for ((<contour>)) explicitly by values with the option (({levels})).
@@ -57,7 +50,7 @@ require "numru/misc"
     is effective only for the next call of ((<contour>)).
   * ((<tone>))
     Color tone or shading by selecting the first 2 dimensions 
-    (with ((<first2D>))) if (({gphys})) is more than 3D.
+    (with GPhys#first2D) if (({gphys})) is more than 3D.
   * ((<set_tone_levels>))
     Set tone levels for ((<tone>)) explicitly by values.
   * ((<clear_tone_levels>))
@@ -111,30 +104,6 @@ require "numru/misc"
   * ((<um_set_params>))
     Calls (({DCL.umpset})) multiple times (for each key and val of (({hash}))).
 
-=class NumRu::GPhys (methods added)
-
-The following methods are added to GPhys.
-
-==Instance Methods
----first1D
-    Returns a 1D subset selecting the first elements of 2nd, 3rd, ..
-    dimensions, i.e., self[true, 0, 0, ...].
-
-    ARGUMENTS
-    * (none)
-
-    RETURN VALUE
-    * a GPhys
-
----first2D
-    Returns a 2D subset selecting the first elements of 3rd, 4th, ..
-    dimensions, i.e., self[true, true, 0, 0, ...].
-
-    ARGUMENTS
-    * (none)
-
-    RETURN VALUE
-    * a GPhys
 
 =module NumRu::GGraph
 
@@ -314,7 +283,7 @@ library if you like.
     * see ((<axes>)).
 
 ---line(gphys, newframe=true, options=nil)
-    Plot a poly-line by selecting the first dimension (with ((<first1D>)))
+    Plot a poly-line by selecting the first dimension (with GPhys#first1D)
     if (({gphys})) is more than 2D.
 
     ARGUMENTS
@@ -368,7 +337,7 @@ library if you like.
     * nil
 
 ---contour(gphys, newframe=true, options=nil)
-    Contour plot by selecting the first 2 dimensions (with ((<first2D>)))
+    Contour plot by selecting the first 2 dimensions (with GPhys#first2D)
     if (({gphys})) is more than 3D.
 
     Contour levels are determined as follows:
@@ -459,7 +428,7 @@ library if you like.
 
 ---tone(gphys, newframe=true, options=nil)
     Color tone or shading by selecting the first 2 dimensions 
-    (with ((<first2D>))) if (({gphys})) is more than 3D.
+    (with GPhys#first2D) if (({gphys})) is more than 3D.
 
     Tone levels are determined as follows:
     * Tone levels are set in this method if not set by
@@ -1060,20 +1029,6 @@ module NumRu
 
   end
 
-############################################################
-  # methods added to GPhys
-  class GPhys
-    def first2D
-      raise "rank less than 2" if rank < 2
-      self[true,true,*([0]*(rank-2))]
-    end
-    def first1D
-      raise "rank less than 1" if rank < 1
-      self[true,*([0]*(rank-1))]
-    end
-  end
-
-############################################################
 
   module GGraph
 
@@ -1226,19 +1181,17 @@ module NumRu
     end
 
     def _get_axinfo(vary)
-      if vary.is_a?(VArray)
-        raise "Not 1D" if vary.rank!=1
-        hash = {
-                'title'=>(vary.get_att('long_name') || vary.name), #.gsub('_','' )
-                'units'=>(vary.get_att('units') || '')             #.gsub('_',' ')
-               }
-      elsif vary.nil?
+      if vary.nil?
         hash = {
                 'title'=>'',
                 'units'=>''
                }
       else
-        raise TypeError,"not a VArray or nil" 
+        raise "Not 1D" if vary.rank!=1
+        hash = {
+                'title'=>(vary.get_att('long_name') || vary.name), #.gsub('_','' )
+                'units'=>(vary.get_att('units') || '')             #.gsub('_',' ')
+               }
       end
       hash 
     end
