@@ -1,6 +1,5 @@
 # The root file to load the entire gphys package except GGraph.
 
 require 'numru/gphys/gphys'
-require "numru/gphys/gphys_netcdf_io"
-require "numru/gphys/gphys_grads_io"
+require "numru/gphys/gphys_io"
 require 'numru/gphys/gphys_fft'
