@@ -194,7 +194,8 @@ module NumRu
 	 when Fixnum
 	    pos=@pos[slicer]
 	    cval = ( pos.val.is_a?(Numeric) ? pos.val : pos.val[0] )
-	    info_lost = "#{self.name}=#{sprintf("%g",cval)}"
+	    sval = sprintf("%g",cval)
+	    info_lost = "#{self.name}=#{sval}"
 	    if (units = pos.get_att('units'))   # substitution
 	      info_lost += " "+units
 	    end
@@ -253,7 +254,7 @@ module NumRu
 	 if @aux
 	    @aux.each{ |name, vary|
 #	       if (aux=vary[slicer]).rank != 0
-		  newax.set_aux(name, aux)
+		  newax.set_aux(name, vary[slicer])
 #	       else
 #		  print "WARNING #{__FILE__}:#{__LINE__} auxiliary VArray #{name} is eliminated\n"
 #	       end
@@ -296,17 +297,19 @@ module NumRu
 	  # find the nearst point
 	  pt = coord_cutter       
 	  dx = (ax-pt).abs
-	  slicer = dx.length-1   # initialization
-	  for i in 0...(dx.length-1)
-	    if dx[i]<=dx[i+1]
-	      if conserve_rank
-		slicer=i..i
-	      else
-		slicer=i
-	      end
-	      break
-	    end
+	  minloc = _minloc_(dx)
+	  if conserve_rank
+	    slicer=minloc..minloc
+	  else
+	    slicer=minloc
 	  end
+	when Array, NArray
+	  # find the nearst points
+	  ary = coord_cutter
+	  slicer = ary.collect{ |pt|
+	    dx = (ax-pt).abs
+	    minloc = _minloc_(dx)
+	  }
 	else
 	  raise TypeError, "(#{coord_cutter.inspect}) is not accepted as a coordinate selector"
 	end
@@ -315,6 +318,15 @@ module NumRu
       end
       private :_cut_
 
+      def _minloc_(a)  # private to be used in _cut_ 
+        # Developper's MEMO: Such a method should be supported in NArray
+        minloc = 0  # initialization
+        for i in 0...(a.length-1)   # here, do not assume monotonic
+	  minloc = i+1 if a[i+1]<a[i]
+	end
+	minloc
+      end
+      private :_minloc_
 
       def set_cell_guess_bounds(center, name=nil)
 	 # derive bounds with a naive assumption (should be OK for
@@ -359,15 +371,19 @@ module NumRu
       def integrate(ary,dim)
 	 if !@integ_wieght; _set_default_integ_weight; end
 	 sh = (0...ary.rank).collect{|i| (i==dim) ? @integ_weight.length : 1 }
+	 mn = sprintf("%g", ( UNumeric===(a=@pos.min) ? a.val : a) )
+         mx = sprintf("%g", ( UNumeric===(a=@pos.max) ? a.val : a) )
 	 return [ ( ary * @integ_weight.reshape(*sh) ).sum(dim), 
-	          "integrated  "+@name+":#{sprintf("%g",@pos.min)}..#{sprintf("%g",@pos.max)}" ]
+	          "integrated  "+@name+":#{mn}..#{mx}" ]
       end
 
       def average(ary,dim)
 	 if !@avg_weight; _set_default_avg_weight; end
 	 sh = (0...ary.rank).collect{|i| (i==dim) ? @avg_weight.length : 1 }
+	 mn = sprintf("%g", ( UNumeric===(a=@pos.min) ? a.val : a) )
+         mx = sprintf("%g", ( UNumeric===(a=@pos.max) ? a.val : a) )
 	 return [ ( ary * @avg_weight.reshape(*sh) ).sum(dim), 
-	          "averaged  "+@name+":#{sprintf("%g",@pos.min)}..#{sprintf("%g",@pos.max)}" ]
+	          "averaged  "+@name+":#{mn}..#{mx}" ]
       end
 
 
@@ -484,6 +500,8 @@ if $0 == __FILE__
    p axcel_b.cut(4.3)
    axcut, slicer = axcel_c.cut(3.0..7.0)
    p axcut.copy, slicer
+   p axcel_b.cut([3.2, 2.5, 6.9])
+   exit
    p axpt
    axcel_c.set_aux('aux1',xc*4)
    p axcel_c.flatten
