@@ -1,3 +1,28 @@
+=begin
+=class NumRu::GPhys
+
+==Instance Methods
+---first1D
+    Returns a 1D subset selecting the first elements of 2nd, 3rd, ..
+    dimensions, i.e., self[true, 0, 0, ...]. (For graphics)
+
+    ARGUMENTS
+    * (none)
+
+    RETURN VALUE
+    * a GPhys
+
+---first2D
+    Returns a 2D subset selecting the first elements of 3rd, 4th, ..
+    dimensions, i.e., self[true, true, 0, 0, ...]. (For graphics)
+
+    ARGUMENTS
+    * (none)
+
+    RETURN VALUE
+    * a GPhys
+=end
+
 require "numru/gphys/grid"
 require "numru/misc/md_iterators"
 
@@ -131,6 +156,17 @@ module NumRu
 	 @grid.dim_index( dimname )
       end
 
+      ## For graphics -->
+      def first2D
+	raise "rank less than 2" if rank < 2
+	self[true,true,*([0]*(rank-2))]
+      end
+      def first1D
+	raise "rank less than 1" if rank < 1
+	self[true,*([0]*(rank-1))]
+      end
+      ## <-- For graphics
+
       def coerce(other)
 	case other
 	when Numeric
