@@ -65,14 +65,14 @@ and Rational, a standard library.
 ---convert2
 
     Same as ((<convert>)), but returns ((|self|)) if the units are
-    incompatible (Warned if $VERBOSE).
+    incompatible (Warned).
 
     EXCEPTION
     * none
 
     WARING MADE
 
-    When $VERBOSE==true, warning is made to $stderr if the following
+    Warning is made to $stderr if the following
     condition is satisfied.
 
     * the units of ((|self|)) and ((|to_units|)) are incompatible.
@@ -110,7 +110,7 @@ and Rational, a standard library.
 
      WARING MADE 
 
-     When $VERBOSE==true, warning is made to $stderr if the following
+     Warning is made to $stderr if the following
      condition is satisfied.
 
      * the units of ((|self|)) and ((|to_units|)) are incompatible.
@@ -163,10 +163,10 @@ module NumRu
       begin
 	convert(to_units)
       rescue
-	if $VERBOSE
-	  $stderr.print(
+	#if $VERBOSE
+	$stderr.print(
                    "WARNING: incompatible units: #{u1.to_s} - #{u2.to_s}\n")
-	end   # warn in Ruby 1.8
+	#end   # warn in Ruby 1.8
 	self
       end
     end
@@ -209,7 +209,7 @@ module NumRu
 	UNumeric.new( v , units )
       when Numeric
 	v = val + other
-	$stderr.print("WARNING: raw Numeric added to #{inspect}\n") if $VERBOSE
+	$stderr.print("WARNING: raw Numeric added to #{inspect}\n") #if $VERBOSE
 	UNumeric.new( v, units )
       when VArray, GPhys
 	ans = other.units.convert2(other, units) + val
@@ -249,8 +249,8 @@ module NumRu
 	  when UNumeric
 	    val #{op} other.convert2( units ).val
 	  when Numeric
-	    $stderr.print("WARNING: raw Numeric added to #{inspect}\n") \
-                 if $VERBOSE   # warn in Ruby 1.8
+	    $stderr.print("WARNING: raw Numeric added to #{inspect}\n") #\
+                # if $VERBOSE   # warn in Ruby 1.8
 	    val #{op} other
 	  when VArray, GPhys
 	    val #{op} other.units.convert2(other, units)
