@@ -1,6 +1,10 @@
 require "numru/gphys/subsetmapping"
 require "numru/gphys/attribute"
 require "narray_miss"
+require "numru/units"
+require "numru/gphys/unumeric"
+require "rational"    # for VArray#sqrt
+require "numru/misc"
 
 module NumRu
 
@@ -91,12 +95,29 @@ NOMENCLATURE
     Set values.
 
     The whole values are set. If you want to set partly, use ((<[]=>)).
+    In this method, values are read from narray and set into the internal
+    value holder. Thus, for exampled, the numeric type is not changed
+    regardress the numeric type of narray. Use ((<replace_val>)) to
+    replace entirely with narray.
 
     ARGUMENTS
     * narray (NArray or NArrayMiss or Numeric): If Numeric, the whole
       values are set to be equal to it. If NArray (or NArrayMiss), its
       shape must agree with the shape of the VArray.
 
+---replace_val(narray)
+
+    Replace the internal array data with the object narray.
+    Use ((<val=>)) if you want to copy the values of narray.
+
+    ARGUMENTS
+    * narray (NArray or NArrayMiss): as pxlained above.
+      Its shape must agree with the shape of the VArray (self).
+
+    RETURN VALUE
+    * if (self.class == VArray), self;
+      otherwise (if self.class is a subclass of VArray), a new VArray.
+
 ---[]
     Get a subset. Its usage is the same as NArray#[]
 
@@ -113,7 +134,7 @@ NOMENCLATURE
     ARGUMENTS -- none
 
     RETURN VALUE
-    * a String ("byte", "sint", "lint", "sfloat", "float", "scomplex"
+    * a String ("byte", "sint", "int", "sfloat", "float", "scomplex"
       "complex", or "obj"). It can be used in NArray.new to initialize
       another NArray.
 
@@ -218,6 +239,10 @@ quoted. See the documentation of NArray for their usage.
 
 ====~ - +
 
+=== Mean etc
+
+====mean, sum, stddev, min, max, median
+
 === Other methods
 
 These methods returns a NArray (not a VArray).
@@ -226,6 +251,12 @@ These methods returns a NArray (not a VArray).
 
 =end
 
+   class Units
+      # for automatic operator generation in VArray
+      def mul!(other); self*other; end
+      def div!(other); self/other; end
+   end    # class Units
+
    class VArray
 
       ### < basic parts to be redefined in subclasses > ###
@@ -273,7 +304,7 @@ These methods returns a NArray (not a VArray).
 	 if @mapping
 	    @varray.ary[*@mapping.slicer]  # 1-step mapping is assumed
 	 else
-	    @ary
+	    @ary.dup
 	 end
       end
 
@@ -286,6 +317,21 @@ These methods returns a NArray (not a VArray).
 	 narray
       end
 
+      def replace_val(narray)
+	narray = __check_ary_class(narray)
+	if narray.shape != shape
+	  raise "shape of the argument (#{narray.shape.inspect}) !="+
+          " self.shape (#{shape.inspect})"
+	end
+	if self.class == VArray
+	  @ary = narray
+	  self
+	else
+	  # subclass --> VArray
+	  VArray.new(narray, attr.copy, name)
+	end
+      end
+
       def ntype
 	 if !@mapping
 	    __ntype(@ary)
@@ -397,6 +443,19 @@ These methods returns a NArray (not a VArray).
       end
       alias put_att set_att
 
+      def units
+	str_units = attr['units']
+	if !str_units || str_units==''
+	  str_units = '1'              # represents non-dimension
+	end
+	Units.new( str_units )
+      end
+
+      def units=(units)
+	attr['units'] = units.to_s
+	units
+      end
+
       def [](*slicer)
 	 mapping = SubsetMapping.new(self.shape_current, slicer)
 	 VArray.new.initialize_mapping(mapping, self)
@@ -423,7 +482,7 @@ These methods returns a NArray (not a VArray).
 	 if @mapping
 	    @varray.name
 	 else
-	    @name
+	    @name.dup
 	 end
       end
 
@@ -433,24 +492,51 @@ These methods returns a NArray (not a VArray).
       ## ToDo: coerce
 
       def coerce(other)
-	 other = NArray.new(self.typecode, 1).coerce(other)[0]
-	 [VArray.new(other,nil,self.name), self]
+	oattr = self.attr.copy
+	oattr['units'] = '1'    # Assume the other to be non-dimensional
+	case other
+	when Numeric
+	  na_other, = NArray.new(self.typecode, 1).coerce(other)   # scalar
+	  c_other = VArray.new(na_other, oattr, self.name)
+	when Array
+	  na = NArray.to_na(other)
+	  c_other = VArray.new(na, oattr, self.name)
+	when NArray
+	  c_other = VArray.new(other, oattr, self.name)
+	else
+	  raise "Cannot coerse #{other.class}"
+	end
+	[c_other, self]
       end
 
-      Math_funcs = ["sqrt","exp","log","log10","log2","sin","cos","tan",
-	    "sinh","cosh","tanh","asin","acos","atan","asinh","acosh",
+      Math_funcs_nondim = ["exp","log","log10","log2","sin","cos","tan",
+	    "sinh","cosh","tanh","asin","acos","atan","atan2","asinh","acosh",
 	    "atanh","csc","sec","cot","csch","sech","coth","acsc","asec",
 	    "acot","acsch","asech","acoth"]
-      Binary_operators = ["+","-","*","/","%","**", 
-	                 ".add!",".sub!",".mul!",".div!","mod!"]
-      Binary_operatorsL = [">",">=","<","<=","&","|","^",
-	    ".eq",".ne",".gt",".ge",".lt",".le",".and",".or",".xor",".not"]
+      Math_funcs = Math_funcs_nondim + ["sqrt"]
+
+      Binary_operators_Uop   = ["*","/","**", ".mul!",".div!"]
+      Binary_operators_Uconv = ["+","-",".add!",".sub!"]
+      Binary_operators_Unone = ["%",".mod!",".imag="]
+      Binary_operators = Binary_operators_Uop + 
+	                 Binary_operators_Uconv +
+	                 Binary_operators_Unone
+
+      Binary_operatorsL_comp = [">",">=","<","<=",
+	                 ".eq",".ne",".gt",".ge",".lt",".le"]
+      Binary_operatorsL_other = ["&","|","^",".and",".or",".xor",".not"]
+      Binary_operatorsL = Binary_operatorsL_comp +
+                          Binary_operatorsL_other
+
       Unary_operators = ["-@","~"]
 
       # type1 methods: returns a VArray with the same shape
       # type2 methods: returns the result directly
       NArray_type1_methods = ["sort", "sort_index", 
-	    "floor","ceil","round","to_f","to_i","to_type"]
+	    "floor","ceil","round","to_f","to_i","to_type","abs",
+	    "real","im","imag","angle","arg","conj","conjugate","cumsum",
+	    "indgen","random"]
+
       NArray_type2_methods1 = ["all?","any?","none?","where","where2",
             "to_a", "to_string"]
       NArray_type2_methods2 = ["rank", "shape", "total","length"]
@@ -462,30 +548,120 @@ These methods returns a NArray (not a VArray).
 	                         push(*NArray_type2_methods2).
 	                         push(*NArray_type2_methods3)
 
-      for f in Math_funcs
+      for f in Math_funcs_nondim
 	 eval <<-EOS, nil, __FILE__, __LINE__+1
 	 #def VArray.#{f}(vary)
          #   raise ArgumentError, "Not a VArray" if !vary.is_a?(VArray)
-	 #   VArray.new( NMath.#{f}(vary.val), vary.attr.copy, vary.name )
+	 #   VArray.new( Misc::EMath.#{f}(vary.val), vary.attr.copy, vary.name )
 	 #end
-	 def #{f}
-	    VArray.new( NMath.#{f}(self.val), self.attr.copy, self.name )
+	 def #{f}(*arg)
+            newattr = self.attr.copy
+            newattr['units'] = '1'
+	    case arg.length
+	    when 0
+	      VArray.new( Misc::EMath.#{f}(self.val), newattr, self.name )
+	    when 1
+	      ar = arg[0].respond_to?(:val) ? arg[0].val : arg[0]
+	      ## ar = ar.to_f   # NMath.atan2 does not work with NArray.int
+	      VArray.new( Misc::EMath.#{f}(self.val, ar), newattr, self.name )
+	    else
+	      raise ArgumentError, "# of args must be 0 or 1"
+	    end
 	 end
          EOS
       end
-      for f in Binary_operators
+      def sqrt
+	va = VArray.new( Misc::EMath.sqrt(self.val), self.attr.copy, self.name )
+	va.units = units**Rational(1,2)
+	va
+      end
+
+      for f in Binary_operators_Uop
 	 eval <<-EOS, nil, __FILE__, __LINE__+1
 	 def #{f.delete(".")}(other)
-            ary = self.val#{f} (other.is_a?(VArray) ? other.val : other)
-	    VArray.new( ary, self.attr.copy, self.name )
+	    case other
+            when VArray, UNumeric
+               ary = self.val#{f}(other.val)
+	       va = VArray.new( ary, self.attr.copy, self.name )
+	       va.units= self.units#{f}(other.units)
+               va
+	    when Numeric, NArray, NArrayMiss, Array
+	       ary = self.val#{f}(other)
+	       va = VArray.new( ary, self.attr.copy, self.name )
+	       if "#{f}" == "**" 
+		 va.units= self.units#{f}(other)
+               end
+               va
+            else
+               c_me, c_other = other.coerce(self)
+               c_me#{f}(c_other)
+            end
 	 end
 	 EOS
       end
-      for f in Binary_operatorsL
+      for f in Binary_operators_Uconv
+	 eval <<-EOS, nil, __FILE__, __LINE__+1
+	 def #{f.delete(".")}(other)
+	    case other
+            when VArray, UNumeric
+               ary = self.val#{f}( other.units.convert2(other.val,units) )
+	       VArray.new( ary, self.attr.copy, self.name )
+	    when Numeric, NArray, NArrayMiss, Array
+	       ary = self.val#{f}(other)
+	       VArray.new( ary, self.attr.copy, self.name )
+            else
+               c_me, c_other = other.coerce(self)
+               c_me#{f}(c_other)
+            end
+	 end
+	 EOS
+      end
+      for f in Binary_operators_Unone
+	 eval <<-EOS, nil, __FILE__, __LINE__+1
+	 def #{f.delete(".")}(other)
+	    case other
+            when VArray, UNumeric
+               ary = self.val#{f}(other.val)
+	       VArray.new( ary, self.attr.copy, self.name )
+	    when Numeric, NArray, NArrayMiss, Array
+	       ary = self.val#{f}(other)
+	       VArray.new( ary, self.attr.copy, self.name )
+            else
+               c_me, c_other = other.coerce(self)
+               c_me#{f}(c_other)
+            end
+	 end
+	 EOS
+      end
+      for f in Binary_operatorsL_comp
 	 eval <<-EOS, nil, __FILE__, __LINE__+1
 	 def #{f.delete(".")}(other)
             # returns NArray
-            self.val#{f} (other.is_a?(VArray) ? other.val : other)
+	    case other
+            when VArray, UNumeric
+               self.val#{f}( other.units.convert2(other.val,units) )
+	    when Numeric, NArray, NArrayMiss, Array
+               self.val#{f}(other)
+            else
+               c_me, c_other = other.coerce(self)
+               self#{f}(other)
+            end
+	 end
+	 EOS
+      end
+      for f in Binary_operatorsL_other
+	 eval <<-EOS, nil, __FILE__, __LINE__+1
+	 def #{f.delete(".")}(other)
+            # returns NArray
+	    case other
+            when VArray, UNumeric
+               self.val#{f}(other.val)
+	    when Numeric, NArray, NArrayMiss, Array
+               self.val#{f}(other)
+            else
+               c_me, c_other = other.coerce(self)
+               self#{f}(other)
+            end
 	 end
 	 EOS
       end
@@ -503,7 +679,9 @@ These methods returns a NArray (not a VArray).
       for f in NArray_type1_methods
 	 eval <<-EOS, nil, __FILE__, __LINE__+1
 	 def #{f}(*args)
-	    VArray.new(self.val.#{f}(*args), self.attr.copy, self.name )
+            newattr = self.attr.copy
+            newattr['units'] = '1' if "#{f}"=="angle" || "#{f}"=="arg"
+	    VArray.new(self.val.#{f}(*args), newattr, self.name )
 	 end
          EOS
       end
@@ -543,7 +721,7 @@ These methods returns a NArray (not a VArray).
             if result.is_a?(NArray) || result.is_a?(NArrayMiss)
 	       VArray.new(result , self.attr.copy, self.name )
             else
-	       result
+	       UNumeric[result, units]    # used to be 'result' (not UNumeric)
             end
 	 end
          EOS
@@ -576,7 +754,7 @@ These methods returns a NArray (not a VArray).
 	 when NArray::SINT
 	    "sint"
 	 when NArray::LINT
-	    "lint"
+	    "int"
 	 when NArray::SFLOAT
 	    "sfloat"
 	 when NArray::DFLOAT
@@ -590,7 +768,7 @@ These methods returns a NArray (not a VArray).
 	 end
       end
 
-   end
+   end    # class VArray
 
 end
 
@@ -600,8 +778,8 @@ end
 if $0 == __FILE__
    include NumRu
    p va = VArray.new( NArray.int(6,2,3).indgen!, nil, 'va' )
+   va.set_att("units","m")
    vs = va[2..4,0,0..1]
-   vs.set_att("units","m")
    p "@@@",vs.rank,vs.shape,vs.total,vs.val,vs.get_att("name")
    vs.val=999
    p "*1*",va
@@ -611,6 +789,9 @@ if $0 == __FILE__
    vt.name='vvvttt'
    p "*5*",(3+vt), vt.sin, vt.cos
    vc = vt.copy
+   p 'atan2'
+   vv = VArray.new( NArray.sfloat(5).indgen!, nil, 'vv' )
+   p vv.atan2(vv).val
    p "eq",vc.eq(vt),vc.equal?(vt)
 
    vd = VArray.new( NArray.int(6).indgen!+10 )
@@ -620,4 +801,13 @@ if $0 == __FILE__
    p va.sort.val
    p vs.to_a, vs.to_string, vs.to_f, vs.to_type(NArray::SINT)
    p "@@@",va.max, va.max(0), va.max(0,1)
+
+   vkg = VArray.new( NArray.float(4,3).indgen!, nil, 'vkg' )
+   vkg.units = 'kg'
+   vg = vkg.copy
+   vg.units = 'g'
+   vmul = vkg*vg
+   p '##', vkg.val, vmul.get_att('units'), vmul.units
+   p '##', (vkg + vg).val, (vg + vkg).val, vkg > vg
+
 end
